aboutsummaryrefslogtreecommitdiffstats
path: root/coin/provisioning/common
diff options
context:
space:
mode:
Diffstat (limited to 'coin/provisioning/common')
-rwxr-xr-xcoin/provisioning/common/fbx_linux.sh62
-rwxr-xr-xcoin/provisioning/common/fbx_macos.sh79
-rw-r--r--coin/provisioning/common/fbx_windows.ps168
-rw-r--r--coin/provisioning/common/mqtt_broker.ps150
-rw-r--r--coin/provisioning/common/mqtt_broker.sh52
-rw-r--r--coin/provisioning/common/vulkansdk.ps1 (renamed from coin/provisioning/common/01-macos-removethemall.sh)33
-rw-r--r--coin/provisioning/common/winrtrunner.ps110
7 files changed, 337 insertions, 17 deletions
diff --git a/coin/provisioning/common/fbx_linux.sh b/coin/provisioning/common/fbx_linux.sh
new file mode 100755
index 00000000..66d4793b
--- /dev/null
+++ b/coin/provisioning/common/fbx_linux.sh
@@ -0,0 +1,62 @@
+#!/bin/bash
+
+#############################################################################
+##
+## Copyright (C) 2017 The Qt Company Ltd.
+## Contact: http://www.qt.io/licensing/
+##
+## This file is part of the provisioning scripts of the Qt Toolkit.
+##
+## $QT_BEGIN_LICENSE:LGPL21$
+## Commercial License Usage
+## Licensees holding valid commercial Qt licenses may use this file in
+## accordance with the commercial license agreement provided with the
+## Software or, alternatively, in accordance with the terms contained in
+## a written agreement between you and The Qt Company. For licensing terms
+## and conditions see http://www.qt.io/terms-conditions. For further
+## information use the contact form at http://www.qt.io/contact-us.
+##
+## GNU Lesser General Public License Usage
+## Alternatively, this file may be used under the terms of the GNU Lesser
+## General Public License version 2.1 or version 3 as published by the Free
+## Software Foundation and appearing in the file LICENSE.LGPLv21 and
+## LICENSE.LGPLv3 included in the packaging of this file. Please review the
+## following information to ensure the GNU Lesser General Public License
+## requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+## http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+##
+## As a special exception, The Qt Company gives you certain additional
+## rights. These rights are described in The Qt Company LGPL Exception
+## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+##
+## $QT_END_LICENSE$
+##
+#############################################################################
+
+# This script installs FBX SDK
+source "${BASH_SOURCE%/*}/DownloadURL.sh"
+#s script installs FBX SDK
+
+set -e
+tarballName="fbx20161_2_fbxsdk_linux.tar.gz"
+targetFolder="/opt/fbx"
+cachedUrl="http://ci-files01-hki.intra.qt.io/input/fbx/$tarballName"
+officialUrl="http://download.autodesk.com/us/fbx_release_older/2016.1.2/$tarballName"
+sha1="b0a08778de025e2c6e90d6fbdb6531f74a3da605"
+tmpFolder="/tmp"
+targetFile="$tmpFolder/$tarballName"
+installer="$tmpFolder/fbx20161_2_fbxsdk_linux"
+
+DownloadURL "$cachedUrl" "$officialUrl" "$sha1" "$targetFile"
+
+sudo tar -C $tmpFolder -xf "$targetFile"
+sudo mkdir -p $targetFolder
+(echo "yes"; echo "n") | sudo "$installer" -w "$tmpFolder" "$targetFolder"
+
+rm -rf "$targetFile"
+
+# Set env variables
+echo "export FBXSDK=$targetFolder" >> ~/.profile
+
+echo "FBX SDK = 2016.1.2" >> ~/versions.txt
+
diff --git a/coin/provisioning/common/fbx_macos.sh b/coin/provisioning/common/fbx_macos.sh
new file mode 100755
index 00000000..66a2d998
--- /dev/null
+++ b/coin/provisioning/common/fbx_macos.sh
@@ -0,0 +1,79 @@
+#!/bin/bash
+#############################################################################
+##
+## Copyright (C) 2017 The Qt Company Ltd.
+## Contact: http://www.qt.io/licensing/
+##
+## This file is part of the provisioning scripts of the Qt Toolkit.
+##
+## $QT_BEGIN_LICENSE:LGPL21$
+## Commercial License Usage
+## Licensees holding valid commercial Qt licenses may use this file in
+## accordance with the commercial license agreement provided with the
+## Software or, alternatively, in accordance with the terms contained in
+## a written agreement between you and The Qt Company. For licensing terms
+## and conditions see http://www.qt.io/terms-conditions. For further
+## information use the contact form at http://www.qt.io/contact-us.
+##
+## GNU Lesser General Public License Usage
+## Alternatively, this file may be used under the terms of the GNU Lesser
+## General Public License version 2.1 or version 3 as published by the Free
+## Software Foundation and appearing in the file LICENSE.LGPLv21 and
+## LICENSE.LGPLv3 included in the packaging of this file. Please review the
+## following information to ensure the GNU Lesser General Public License
+## requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+## http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+##
+## As a special exception, The Qt Company gives you certain additional
+## rights. These rights are described in The Qt Company LGPL Exception
+## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+##
+## $QT_END_LICENSE$
+##
+#############################################################################
+
+# This script installs FBX SDK
+
+# shellcheck source=./try_catch.sh
+source "${BASH_SOURCE%/*}/try_catch.sh"
+
+fileName="fbx20161_2_fbxsdk_clang_mac.pkg.tgz"
+targetFolder="/opt/fbx"
+cachedUrl="/net/ci-files01-hki.intra.qt.io/hdd/www/input/fbx/$fileName"
+officialUrl="http://download.autodesk.com/us/fbx_release_older/2016.1.2/$fileName"
+sha1="f82535423c700c605320c52e13e781c92208ec6b"
+targetFolder="/tmp"
+targetFile="$targetFolder/$fileName"
+installer="$targetFolder/fbx20161_2_fbxsdk_clang_macos.pkg"
+
+ExceptionExtractPrimaryUrl=100
+
+try
+(
+ echo "Extracting '$cachedUrl'"
+ tar -xzf "$cachedUrl" -C "$targetFolder" || throw $ExceptionExtractPrimaryUrl
+)
+catch || {
+ case $ex_code in
+ $ExceptionExtractPrimaryUrl)
+ set -e
+ echo "Failed to uncompress from '$cachedUrl'"
+ echo "Downloading from '$officialUrl'"
+ curl --fail -L --retry 5 --retry-delay 5 -o "$targetFile" "$officialUrl" || exit 1;
+ echo "Checking SHA1 on PKG '$targetFile'"
+ echo "$sha1 *$targetFile" > $targetFile.sha1
+ shasum --check $targetFile.sha1
+ echo "Extracting '$targetFile'"
+ tar -xzf "$targetFile" -C "$targetFolder" || exit 1;
+ ;;
+ esac
+}
+set -e
+rm -rf "$targetFile"
+echo "Running installer for '$installer'"
+sudo installer -pkg "$installer" -target "/"
+
+# Set env variables
+echo "export FBXSDK=/Applications/Autodesk/FBX\ SDK/2016.1.2/" >> ~/.bashrc
+echo "FBX SDK = 2016.1.2" >> ~/versions.txt
+
diff --git a/coin/provisioning/common/fbx_windows.ps1 b/coin/provisioning/common/fbx_windows.ps1
new file mode 100644
index 00000000..00de579d
--- /dev/null
+++ b/coin/provisioning/common/fbx_windows.ps1
@@ -0,0 +1,68 @@
+############################################################################
+##
+## Copyright (C) 2017 The Qt Company Ltd.
+## Contact: http://www.qt.io/licensing/
+##
+## This file is part of the provisioning scripts of the Qt Toolkit.
+##
+## $QT_BEGIN_LICENSE:LGPL21$
+## Commercial License Usage
+## Licensees holding valid commercial Qt licenses may use this file in
+## accordance with the commercial license agreement provided with the
+## Software or, alternatively, in accordance with the terms contained in
+## a written agreement between you and The Qt Company. For licensing terms
+## and conditions see http://www.qt.io/terms-conditions. For further
+## information use the contact form at http://www.qt.io/contact-us.
+##
+## GNU Lesser General Public License Usage
+## Alternatively, this file may be used under the terms of the GNU Lesser
+## General Public License version 2.1 or version 3 as published by the Free
+## Software Foundation and appearing in the file LICENSE.LGPLv21 and
+## LICENSE.LGPLv3 included in the packaging of this file. Please review the
+## following information to ensure the GNU Lesser General Public License
+## requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+## http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+##
+## As a special exception, The Qt Company gives you certain additional
+## rights. These rights are described in The Qt Company LGPL Exception
+## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+##
+## $QT_END_LICENSE$
+##
+#############################################################################
+
+. "$PSScriptRoot\helpers.ps1"
+
+# This script will install FBX SDK
+
+$version = "2016.1.2"
+
+$name = "fbx20161_2_fbxsdk_vs2015_win"
+$packageName = "$name.7z"
+$installerName = "$name.exe"
+$cacheUrl = "\\ci-files01-hki.intra.qt.io\provisioning\fbx\$packageName"
+$sha1 = "3690400625672bef6369bcf90dcde4d78b493b24"
+
+# The executable is an interactive installer only. We can't run it in a script silently.
+# $officialUrl = "http://download.autodesk.com/us/fbx_release_older/2016.1.2/$installerName"
+# This sha is for the executable
+# $sha1 = "54f581c7c19cf5a08cf5e7bc62b8cc7f0617558e"
+
+#$targetFile = "C:\Windows\Temp\$packageName"
+$targetFolder = "C:\Program Files\"
+
+#echo "Downloading '$installerName'"
+#Download $officialUrl $cacheUrl $targetFile
+#Verify-Checksum $targetFile $sha1
+
+echo "Extracting '$cacheUrl'"
+#Extract-7Zip $cacheUrl $targetFolder
+Start-Process -FilePath "C:\Utils\sevenzip\7z.exe" -ArgumentList "x -y `"$cacheUrl`" -o`"$targetFolder`"" -Wait
+
+#Remove-Item -Recurse -Force "$packageName"
+
+echo "Adding environment variables."
+[Environment]::SetEnvironmentVariable("FBXSDK", "$targetFolder\Autodesk\FBX\FBX SDK\2016.1.2", [EnvironmentVariableTarget]::Machine)
+
+echo "FBX SDK = $version" >> ~\versions.txt
+
diff --git a/coin/provisioning/common/mqtt_broker.ps1 b/coin/provisioning/common/mqtt_broker.ps1
new file mode 100644
index 00000000..610f22d8
--- /dev/null
+++ b/coin/provisioning/common/mqtt_broker.ps1
@@ -0,0 +1,50 @@
+#############################################################################
+##
+## Copyright (C) 2017 The Qt Company Ltd.
+## Contact: http://www.qt.io/licensing/
+##
+## This file is part of the test suite of the Qt Toolkit.
+##
+## $QT_BEGIN_LICENSE:LGPL21$
+## Commercial License Usage
+## Licensees holding valid commercial Qt licenses may use this file in
+## accordance with the commercial license agreement provided with the
+## Software or, alternatively, in accordance with the terms contained in
+## a written agreement between you and The Qt Company. For licensing terms
+## and conditions see http://www.qt.io/terms-conditions. For further
+## information use the contact form at http://www.qt.io/contact-us.
+##
+## GNU Lesser General Public License Usage
+## Alternatively, this file may be used under the terms of the GNU Lesser
+## General Public License version 2.1 or version 3 as published by the Free
+## Software Foundation and appearing in the file LICENSE.LGPLv21 and
+## LICENSE.LGPLv3 included in the packaging of this file. Please review the
+## following information to ensure the GNU Lesser General Public License
+## requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+## http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+##
+## As a special exception, The Qt Company gives you certain additional
+## rights. These rights are described in The Qt Company LGPL Exception
+## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+##
+## $QT_END_LICENSE$
+##
+#############################################################################
+
+. "$PSScriptRoot\helpers.ps1"
+
+echo "MQTT: Downloading Paho test broker..."
+$zip = "c:\users\qt\downloads\pahotest.zip"
+$externalUrl = "https://github.com/eclipse/paho.mqtt.testing/archive/c342c09dadc7a664d0a8befad1ca031f5a0b0bc0.zip"
+$internalUrl = "http://ci-files01-hki.ci.local/input/mqtt_broker/paho.mqtt.testing-c342c09dadc7a664d0a8befad1ca031f5a0b0bc0.zip"
+$sha1 = "532fe145096cdd8d679f425cbfd883289150c968"
+
+Download $externalUrl $internalUrl $zip
+Verify-Checksum $zip $sha1
+
+echo "MQTT: Installing $zip..."
+Extract-Zip $zip C:\Utils
+Remove-Item $zip
+
+echo "MQTT: Updating environment..."
+[Environment]::SetEnvironmentVariable("MQTT_TEST_BROKER_LOCATION", "C:\Utils\paho.mqtt.testing-c342c09dadc7a664d0a8befad1ca031f5a0b0bc0\interoperability\startbroker.py", "Machine")
diff --git a/coin/provisioning/common/mqtt_broker.sh b/coin/provisioning/common/mqtt_broker.sh
new file mode 100644
index 00000000..b52b78b1
--- /dev/null
+++ b/coin/provisioning/common/mqtt_broker.sh
@@ -0,0 +1,52 @@
+#!/bin/bash
+
+#############################################################################
+##
+## Copyright (C) 2017 The Qt Company Ltd.
+## Contact: http://www.qt.io/licensing/
+##
+## This file is part of the test suite of the Qt Toolkit.
+##
+## $QT_BEGIN_LICENSE:LGPL21$
+## Commercial License Usage
+## Licensees holding valid commercial Qt licenses may use this file in
+## accordance with the commercial license agreement provided with the
+## Software or, alternatively, in accordance with the terms contained in
+## a written agreement between you and The Qt Company. For licensing terms
+## and conditions see http://www.qt.io/terms-conditions. For further
+## information use the contact form at http://www.qt.io/contact-us.
+##
+## GNU Lesser General Public License Usage
+## Alternatively, this file may be used under the terms of the GNU Lesser
+## General Public License version 2.1 or version 3 as published by the Free
+## Software Foundation and appearing in the file LICENSE.LGPLv21 and
+## LICENSE.LGPLv3 included in the packaging of this file. Please review the
+## following information to ensure the GNU Lesser General Public License
+## requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+## http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+##
+## As a special exception, The Qt Company gives you certain additional
+## rights. These rights are described in The Qt Company LGPL Exception
+## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+##
+## $QT_END_LICENSE$
+##
+#############################################################################
+
+# This script installs paho testing broker
+
+# shellcheck source=../common/InstallFromCompressedFileFromURL.sh
+source "${BASH_SOURCE%/*}/../common/InstallFromCompressedFileFromURL.sh"
+
+CommitSHA="c342c09dadc7a664d0a8befad1ca031f5a0b0bc0"
+PrimaryUrl="https://github.com/eclipse/paho.mqtt.testing/archive/$CommitSHA.zip"
+AltUrl="http://ci-files01-hki.ci.local/input/mqtt_broker/paho.mqtt.testing-$CommitSHA.zip"
+SHA1="532fe145096cdd8d679f425cbfd883289150c968"
+targetFolder="/opt/paho_broker"
+appPrefix="paho.mqtt.testing-$CommitSHA"
+
+sudo rm -fr "$targetFolder"
+InstallFromCompressedFileFromURL "$PrimaryUrl" "$AltUrl" "$SHA1" "$targetFolder" "$appPrefix"
+
+echo "Adding MQTT broker path to environment"
+sed -i "1iexport MQTT_TEST_BROKER_LOCATION=$targetFolder/interoperability/startbroker.py" ~/.bashrc
diff --git a/coin/provisioning/common/winrtrunner.ps1 b/coin/provisioning/common/winrtrunner.ps1
new file mode 100644
index 00000000..f433ac7a
--- /dev/null
+++ b/coin/provisioning/common/winrtrunner.ps1
@@ -0,0 +1,10 @@
+. "$PSScriptRoot\helpers.ps1"
+
+$zip = "c:\users\qt\downloads\winrtrunner.zip"
+
+Invoke-WebRequest -UseBasicParsing http://download.qt.io/development_releases/prebuilt/winrtrunner/winrtrunner.zip -OutFile $zip
+Verify-Checksum $zip "C19098A4C9DBD20EDEB4E5E0D3E6A5BBBCA73C42"
+Extract-Zip $zip C:\Utils\winrtrunner
+Remove-Item $zip
+
+[Environment]::SetEnvironmentVariable("CI_WINRTRUNNER_PATH", "C:\Utils\winrtrunner", "Machine")
diff --git a/coin/provisioning/common/01-macos-removethemall.sh b/coin/provisioning/common/vulkansdk.ps1
index f0e26480..c572fa47 100644
--- a/coin/provisioning/common/01-macos-removethemall.sh
+++ b/coin/provisioning/common/vulkansdk.ps1
@@ -1,10 +1,9 @@
-#!/bin/sh
-#############################################################################
+############################################################################
##
-## Copyright (C) 2016 The Qt Company Ltd.
+## Copyright (C) 2017 The Qt Company Ltd.
## Contact: http://www.qt.io/licensing/
##
## This file is part of the test suite of the Qt Toolkit.
##
## $QT_BEGIN_LICENSE:LGPL21$
## Commercial License Usage
@@ -32,18 +31,18 @@
##
#############################################################################
-function RemoveDir {
- param=$1
+. "$PSScriptRoot\..\common\helpers.ps1"
+
+# This script will install Vulkan SDK
+
+$version = "1.0.51.0"
+$url_cache = "\\ci-files01-hki.ci.local\provisioning\windows\VulkanSDK-" +$version+ "-Installer.exe"
+$vulkanPackage = "C:\Windows\Temp\vulkan-installer-$version.exe"
+
+Copy-Item $url_cache $vulkanPackage
+cmd /c "$vulkanPackage /S"
- if [ ! -d $param ]
- then
- echo "'$param' don't exists"
- else
- echo "Removing $param..."
- sudo rm -fr $param
- fi
-}
+echo "Cleaning $vulkanPackage.."
+Remove-Item -Recurse -Force "$vulkanPackage"
-# Remove Android
-param="/opt/android"
-RemoveDir $param
+echo "Vulkan SDK = $version" >> ~\versions.txt
@@ -1,10 +1,9 @@
## Contact: http://www.qt.io/licensing/
##
-## This file is part of the test suite of the Qt Toolkit.
+## This file is part of the provisioning scripts of the Qt Toolkit.
##
## $QT_BEGIN_LICENSE:LGPL21$